@@ -21,7 +21,7 @@ use Scalar::Util ();		# Core since 5.7.3
 use Storable ();		# Core since 5.7.3
 use Test::Builder ();		# Core since 5.6.2
 
-our $VERSION = '0.000_906';
+our $VERSION = '0.000_907';
 
 use constant ON_DARWIN		=> 'darwin' eq $^O;
 use constant ON_VMS		=> 'VMS' eq $^O;
@@ -39,6 +39,10 @@ use constant NON_REF	=> ref 0;
 use constant REGEXP_REF	=> ref qr<x>smx;
 use constant SCALAR_REF	=> ref \0;
 
+# Pod::Simple versions earlier than this were too restrictive in
+# recognizing 'man' links, so some valid ones ended up classified as
+# 'pod'. We conditionalize fix-up code on this constant so that, if the
+# fix-up is not needed, the optimizer ditches it.
 use constant NEED_MAN_FIX	=> Pod::Simple->VERSION lt '3.24';
 
 # NOTE that Test::Builder->new() gets us a singleton. For this reason I
@@ -84,6 +88,10 @@ sub _default_agent {
     return HTTP::Tiny->new()->agent();
 }
 
+sub _default_allow_man_spaces {
+    return 0;
+}
+
 sub _default_check_external_sections {
     return 1;
 }
@@ -133,6 +141,12 @@ sub _init_agent {
     return;
 }
 
+sub _init_allow_man_spaces {
+    my ( $self, $name, $value ) = @_;
+    $self->{$name} = $value ? 1 : 0;
+    return;
+}
+
 sub _init_check_external_sections {
     my ( $self, $name, $value ) = @_;
     $self->{$name} = $value ? 1 : 0;
@@ -262,6 +276,11 @@ sub all_pod_files_ok {
     return wantarray ? ( $fail, $pass, $skip ) : $fail;
 }
 
+sub allow_man_spaces {
+    my ( $self ) = @_;
+    return $self->{allow_man_spaces}
+}
+
 sub check_external_sections {
     my ( $self ) = @_;
     return $self->{check_external_sections}
@@ -272,6 +291,36 @@ sub check_url {
     return $self->{check_url}
 }
 
+sub configuration {
+    my ( $self, $leader ) = @_;
+
+    defined $leader
+	or $leader = '';
+    $leader =~ s/ (?<= \S ) \z / /smx;
+
+    my ( $ignore_url ) = $TEST->explain( scalar $self->ignore_url() );
+    chomp $ignore_url;
+
+    return <<"EOD";
+${leader}'agent' is '@{[ $self->agent() ]}'
+${leader}'allow_man_spaces' is @{[ _Boolean(
+    $self->allow_man_spaces() ) ]}
+${leader}'check_external_sections' is @{[ _Boolean(
+    $self->check_external_sections() ) ]}
+${leader}'check_url' is @{[ _Boolean( $self->check_url() ) ]}
+${leader}'ignore_url' is $ignore_url
+${leader}'man' is @{[ _Boolean( $self->man() ) ]}
+${leader}'module_index' is ( @{[ join ', ', map { "'$_'" }
+    $self->module_index() ]} )
+${leader}'require_installed' is @{[ _Boolean( $self->require_installed() ) ]}
+EOD
+}
+
+sub _Boolean {
+    my ( $value ) = @_;
+    return $value ? 'true' : 'false';
+}
+
 sub ignore_url {
     my ( $self ) = @_;
     my $spec = $self->__ignore_url();
@@ -469,13 +518,37 @@ sub _get_installed_doc_info {
 # POD link handlers
 
 # Handle a 'man' link.
+
 sub _handle_man {
     my ( $self, $link ) = @_;
-    my $rslt = $self->_is_man_page( $link )
+
+    $self->man()
+	or return $self->_skip( $link, 'not checked; man checks disabled' );
+
+    $link->[1]{to}
+	or return $self->_fail( $link, 'no man page specified' );
+
+    my ( $page, $sect ) = $link->[1]{to} =~ m/
+	    ( [^(]+ ) (?: [(] ( [^)]+ ) [)] )? /smx
+	or return $self->_fail( $link, 'not recognized as man page spec' );
+
+    $page =~ s/ \A \s+ //smx;
+    $page =~ s/ \s+ \z //smx;
+
+    $page =~ m/ \s /smx
+	and not $self->allow_man_spaces()
+	and return $self->_fail( $link, 'contains embedded spaces' );
+
+    my @pg = (
+	$sect ? $sect : (),
+	$page,
+    );
+
+    ( $self->{_cache}{man}{"@pg"} ||= IPC::Cmd::run( COMMAND => [
+		qw{ man -w }, @pg ] ) || 0 )
 	and return 0;
-    defined $rslt
-	and return $self->_fail( $link, 'refers to unknown man page' );
-    return $self->_skip( $link, 'not checked; man checks disabled' );
+
+    return $self->_fail( $link, 'refers to unknown man page' );
 }
 
 # Handle pod links. This is pretty much everything, except for 'man'
@@ -562,24 +635,6 @@ sub _check_external_pod_info {
 	return $self->_fail( $link, 'links to unknown section' );
     }
 
-=begin comment
-
-    # The following code was cargo-culted in from Test::Pod::LinkCheck.
-    # But I am unsure if it ever actually catches any man links. The
-    # case I have had trouble with parses (in my own parlance) as a
-    # local link -- i.e. the link has a {section} key but no {to} key/
-
-    # If there is no section, it might be a man page, even though the
-    # parser did not parse it as one
-    unless ( $section ) {
-	$self->_is_man_page( $link )
-	    and return 0;
-    }
-
-=end comment
-
-=cut
-
     # If we're requiring links to be to installed modules, flunk now.
     $self->require_installed()
 	and return $self->_fail( $link,
@@ -754,25 +809,6 @@ sub _handle_url {
     }
 }
 
-# Returns true if the link refers to a man page, false (but defined) if
-# it does not, and undef if it could not be checked.
-sub _is_man_page {
-    my ( $self, $link ) = @_;
-    $self->man()
-	or return;
-    $link->[1]{to}
-	or return;
-    my ( $page, $sect ) = $link->[1]{to} =~ m/ ( [^(]+ ) (?: [(] ( [^)]+ ) [)] )? /smx
-	or return;
-    $page =~ s/ \s+ \z //smx;
-    my @pg = (
-	$sect ? $sect : (),
-	$page,
-    );
-    return $self->{_cache}{man}{"@pg"} ||= IPC::Cmd::run( COMMAND => [
-	    qw{ man -w }, @pg ] ) || 0;
-}
-
 sub _is_perl_file {
     my ( undef, $path ) = @_;
     -e $path
@@ -1055,6 +1091,15 @@ This argument is the user agent string to use for web access.
 
 The default is that of L<HTTP::Tiny|HTTP::Tiny>.
 
+=item allow_man_spaces
+
+This Boolean argument is set true to allow internal spaces in a 'man'
+link. B<Note> that such links can not be checked under some operating
+systems (e.g. FreeBSD) because the L<man (1)> program splits its
+arguments on spaces.
+
+The default is false.
+
 =item check_external_sections
 
 This Boolean argument is true if the sections of links outside the
@@ -1182,6 +1227,13 @@ If called in scalar context, this method returns the number of test
 failures encountered. If called in list context it return the number of
 failures, passes, and skipped tests, in that order.
 
+=head2 allow_man_spaces
+
+ $t->allow_man_spaces()
+   and say 'Embedded spaces are allowed in man page names';
+
+This method returns the value of the C<'allow_man_spaces'> attribute.
+
 =head2 check_external_sections
 
  $t->check_external_sections()
@@ -1195,6 +1247,14 @@ This method returns the value of the C<'check_url'> attribute.
 
 This method returns the value of the C<'check_url'> attribute.
 
+=head2 configuration
+
+ say $t->configuration( '    ' );
+
+This convenience method returns a string containing all attributes of
+the object in human-readable form. The argument, if any, is prefixed to
+each line of the returned string.
+
 =head2 ignore_url
 
  print 'Ignored URLs ', join ', ', $t->ignore_url();
